@@ -73,7 +73,7 @@ static long filepos[2];		/* file positions of input file(s) */
 
 static int intype;	/* type of input file */
 static int inlen;	/* line length for files with dBase files */
-static int toolong;	/* flag: string data longer than specified encountered? */
+static int toolong;	/* count: string data longer than specified encountered? */
 
 char *dap_title = NULL;	/* title for .lst pages, caption for .ps pages */
 
@@ -934,7 +934,7 @@ int step()
 		      value, dap_obs[dap_ono].do_len[dap_obs[dap_ono].do_in[v]]);
 	      dap_obs[dap_ono].do_str[dap_obs[dap_ono].do_in[v]]
 		[dap_obs[dap_ono].do_len[dap_obs[dap_ono].do_in[v]]] = '\0';
-	      if (!toolong)
+	      if (toolong < dap_toolong)
 		{
 		  fprintf(dap_log,
 			  "(step (%s:%d)) WARNING: string data too long (%d) for %s (%d): %s\n",
@@ -943,7 +943,7 @@ int step()
 			  dap_obs[dap_ono].do_nam[dap_obs[dap_ono].do_in[v]],
 			  dap_obs[dap_ono].do_len[dap_obs[dap_ono].do_in[v]],
 			  value);
-		  toolong = 1;
+		  toolong++;
 		}
 	    }
 	}
@@ -2749,8 +2749,8 @@ void merge(char *fname1, char *vars1, char *fname2, char *vars2,
 	}
       if (v2 < nvar2)
 	{
-	  fprintf(dap_err, "(merge) variable appears in both lists: %s\n",
-		  dap_obs[0].do_nam[varv1[v1]]);
+	  fprintf(dap_err, "(merge) variable appears in lists for both %s and %s: %s\n",
+		  fname1, fname2, dap_obs[0].do_nam[varv1[v1]]);
 	  exit(1);
 	}
       else
