@@ -1306,13 +1306,13 @@ static int findparam(char *pname, char *param[], int nparam)
 
 void estimate(char *fname, char *parameters, char *definitions, char *part)
 {
-  char *parammem;		/* memory to hold parameter names */
+  char *parammem;       /* memory to hold parameter names */
   char **param;		/* pointers to parameter names */
   int start, end;	/* for stepping through 'definitions' */
   int nparam;		/* number of parameters */
   int p, p1;		/* index to parameter arrays */
   int defstate;		/* 0 = new def, 1 = got '=' */
-  double *defmem;		/* memory for def */
+  double *defmem;	/* memory for def */
   double **def;		/* definition for each parameter: each entry contains the
                          * coefficient for the parameter in the def or 0 if not in the def
 			 */
@@ -1323,14 +1323,14 @@ void estimate(char *fname, char *parameters, char *definitions, char *part)
   int defnum;		/* number of parameter being defined */
   int ninput;		/* number of parameters to read in */
   double *estimate;	/* vector of estimates */
-  double *covmem;		/* memory for covariance matrix */
+  double *covmem;	/* memory for covariance matrix */
   double **cov;		/* covariance matrix */
   int typen, param1n, param2n, covn;	/* indices of input variables */
   int more;		/* for checking if there are more data lines to read in */
   int *partv;		/* indices of the partitioning variables */
   int npart;		/* number of partitioning variables */
 
-  parammem = dap_malloc(strlen(definitions) + 1, "");
+  parammem = dap_malloc(strlen(parameters) + strlen(definitions) + 1, "");
   /* divide by 2 because params are separated; almost always still too many */
   /* this is just (an overestimate of) the max, not the real nparam */
   nparam = (strlen(parameters) + strlen(definitions)) / 2;
