@@ -174,8 +174,8 @@ void linreg(char fname[], char ylist[], char x0list[], char x1list[],
 void logreg(char fname[], char ylist[], char x0list[], char x1list[],
                                 char marks[], char xname[], double level);
 
-char *dap_malloc(int nbytes, char *vars);
-void dap_free(void *ptr);
+char *dap_malloc(int nbytes, char *mesg);
+void dap_free(void *ptr, char *mesg);
 
 void dap_initpict();
 void dap_putdouble(DFILE *dfp);
@@ -183,3 +183,4 @@ void dap_getdouble(char code[]);
 void dap_putint(int i, DFILE *dfp);
 int dap_getint(char code[]);
 int dap_mnsparse(char *varlist, char *outlist, int *varv, int *wtvar, int stats[]);
+int dap_clearobs(char *varspec);
