@@ -31,6 +31,8 @@ static int mdays[] = { 0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
 int dap_numdate(char date[])        /* number of days since 12/31/1751 */
 {
   int d; /* index to date */
+  int dday; /* start of day */
+  int dyr; /* start of year */
   int mon;
   int day;
   int yr;
@@ -38,16 +40,18 @@ int dap_numdate(char date[])        /* number of days since 12/31/1751 */
   int y;
   int ndays;
 
-  mon = 10 * (date[0] - '0') + date[1] - '0';
-  d = 2;
+  for (d = 0, mon = 0; d < 2 && '0' <= date[d] && date[d] <= '9'; d++)
+    mon = 10 * mon + date[d] - '0';
   if (date[d] == '/')
     d++;
-  day = 10 * (date[d] - '0') + date[d + 1] - '0';
-  d += 2;
+  for (dday = d, day = 0; d < dday + 2 && '0' <= date[d] && date[d] <= '9'; d++)
+    day = 10 * day + date[d] - '0';
   if (date[d] == '/')
     d++;
-  yr = 10 * (10 * (10 * (date[d] - '0') + date[d + 1] - '0') +
-	     date[d + 2] - '0') + date[d + 3] - '0';
+  for (dyr = d, yr = 0; d < dyr + 4 && '0' <= date[d] && date[d] <= '9'; d++)
+    yr = 10 * yr + date[d] - '0';
+  if (d < dyr + 4)
+    return -1;
   for (m = 1, ndays = day; m < mon; m++)
     ndays += mdays[m];
   if ((mon > 2) && !(yr % 4) && (yr % 100))
